Method: Azure::Storage::Mgmt::V2017_10_01::Models::EncryptionService#last_enabled_time
- Defined in:
- lib/2017-10-01/generated/azure_mgmt_storage/models/encryption_service.rb
#last_enabled_time ⇒ DateTime
encryption was last enabled by the user. Only returned when encryption is enabled. There might be some unencrypted blobs which were written after this time, as it is just a rough estimate.
23 24 25 |
# File 'lib/2017-10-01/generated/azure_mgmt_storage/models/encryption_service.rb', line 23 def last_enabled_time @last_enabled_time end |